package ca.mcgill.lmp.finite;

/**
 * A state in a LMP.
 * 
 * @author Alexandre Bouchard
 */
public class State 
{
	private int index;
	private Object description;
	
	/**
	 * Create a state with the provided index. (Used as an index in transition matrices).
	 * @param index
	 */
	public State(int index)
	{
		this.index = index;	
		this.description = "s" + index;
	}
	
	/**
	 * Create a state with the provided index. (Used as an index in transition matrices),
	 * and a description of that state.
	 * @param index
	 * @param description
	 */
	public State(int index, Object description)
	{
		this.index = index;
		this.description = description;
	}

	/**
	 * 
	 * @return The string representation of the description.
	 */
	public String toString() 
	{
		return description.toString();
	}
	
	/**
	 * 
	 * @return
	 */
	public Object getDescription()
	{
		return description;
	}
	
	/**
	 * 
	 * @return
	 */
	public int getIndex()
	{
		return index;
	}
	
	/**
	 * this is equal to state2 iff state2 is an instance of State and they have the 
	 * same index.
	 * @param state2
	 * @return
	 */
	public boolean equals(Object state2) 
	{
		if (state2 instanceof State)
		{
			if (((State) state2).index == this.index)
			{
				return true;
			}
			else
			{
				return false;
			}
		}
		else
		{
			return false;
		}
	}
	
	/**
	 * 
	 * @return The index of this State.
	 */
	public int hashCode() 
	{
		return index;
	}
}
